pub enum KeyFrameStyle {
Computed,
Style(Style),
}Expand description
Defines whether the style in a key frame should be stored in the frame or it it should be pulled from the computed style
Variants
Computed
when computed style, props will be pulled from the computed style
Style(Style)
When using style, the props will be stored in the key frame