pub enum ReverseOnce {
Never,
Val(bool),
}Expand description
Holds the allowance and state of the reverse once property of an animation. Reversing an animation is attempted when animation is being removed or hidden.
Variants
Never
When Never, the animation will not be allowed to be set to be in reverse mode
Val(bool)
When Val, the animation is allowed to be set to reverse until finished.
When Val(true) the animation will actually reverse
Implementations